pub struct Subtitle(pub Opened);
向解码器发送一个 NULL 包以表示流的结束并进入排空模式。
将此类型转换为输入类型的可变引用(通常自动推导)。
将此类型转换为输入类型的共享引用(通常自动推导)。
调用 U::from(self)。
That is, this conversion is whatever the implementation of
From<T> for U 实现选择执行的操作。
🔬This is a nightly-only experimental API. (arbitrary_self_types)
The target type on which the method may be called.